/*
 * Copyright (C) 2003  Diez B. Roggisch [deets@web.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PageDispatcherFactory.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.contrib.dbroggisch.page;

import org.apache.log4j.Logger;
import org.barracudamvc.core.event.DispatcherFactory;
import org.barracudamvc.core.event.EventDispatcher;


/**
 * A simple convenience class providing a ready-set dispatcher factory. The
 * event dispatcher returned in this case provides for thread safety when
 * using session pages.  See {@link PageEventDispatcher} for details.
 *
 * <p>To use this class, return an instance of this factory in the
 * {@link org.barracudamvc.core.event.ApplicationGateway#getDispatcherFactory() AplicationGateway.getDispatcherFactory()}
 * method.</p>
 *
 * @author <a href="mailto:deets@web.de">Diez B. Roggisch</a>
 * @version 1.0
 */
public class PageDispatcherFactory implements DispatcherFactory {

    private static final Logger logger = Logger.getLogger(PageDispatcherFactory.class.getName());

    public EventDispatcher getInstance() {
        if (logger.isDebugEnabled()) logger.debug("Using custom event dispatcher " + PageEventDispatcher.class.getName());
        return new PageEventDispatcher();
    }

}
