/*
 * Copyright (C) 2003  Diez B. Roggisch [deets@web.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: RepopulationFormMap.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.contrib.dbroggisch.repopulation;


import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.log4j.Logger;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BInput;
import org.barracudamvc.core.comp.TemplateDirective;
import org.barracudamvc.core.comp.TemplateModel;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.model.ModelListener;
import org.barracudamvc.core.forms.FormElement;


/**
 * The class <code>RepopulationFormMap</code> provides a convenient way to repopulate
 * HTML form contents.
 *
 * It can be used as a TemplateModel. The values of the defined FormElements are
 * wrapped into a BInput. The BInput sets the name of the FormElement.
 * If a prefix has been given -- either explicit with setPrefix() or implicit by the
 * overloaded map(..)-methods -- it will be prepended to the name.
 *
 * @author <a href="mailto:deets@web.de">Diez Roggisch</a>
 * @version 1.0
 */
public class RepopulationFormMap extends ErrorFormMap implements TemplateModel {
    protected static final Logger logger = Logger.getLogger(RepopulationFormMap.class.getName());

    /**
     * The prefix can be used to limit the
     *
     */
    protected String prefix;

    /**
     * Describe variable <code>modelName</code> here.
     *
     */
    protected String modelName;

    protected ViewContext viewContext = null;
    protected List listeners = new ArrayList();

    protected List _modelChilds = new ArrayList();

    public FormElement defineElement(FormElement element) {
        super.defineElement(element);
        if(element instanceof ChildModelElement) {
            _modelChilds.add(element);
        }
		  return element;
    }

    public FormElement defineElement(java.lang.String key, FormElement element) {
        super.defineElement(key, element);
        if(element instanceof ChildModelElement) {
            _modelChilds.add(element);
        }
		  return element;
    }

    public List getChildModels() {
        List res = new ArrayList();
        for(Iterator it = _modelChilds.iterator(); it.hasNext();) {
            ChildModelElement cme = (ChildModelElement)it.next();
            res.add(cme.getChildModel(modelName, prefix));
        }
        return res;
    }

    /**
     * Describe <code>setPrefix</code> method here.
     *
     * @param prefix a <code>String</code> value
     */
    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }


    /**
     * Describe <code>getPrefix</code> method here.
     *
     * @return a <code>String</code> value
     */
    public String getPrefix() {
        return this.prefix;
    }



//    // These methods simply take care of th prefix
//    /**
//     * Describe <code>map</code> method here.
//     *
//     * @param req a <code>ServletRequest</code> value
//     * @return a <code>FormMap</code> value
//     */
//    public FormMap map(ServletRequest req) {
//        return super.map(req, prefix);
//    }
//
//    /**
//     * Describe <code>map</code> method here.
//     *
//     * @param req a <code>ServletRequest</code> value
//     * @param prefix a <code>String</code> value
//     * @return a <code>FormMap</code> value
//     */
//    public FormMap map(ServletRequest req, String prefix) {
//        this.prefix = prefix;
//        return super.map(req, prefix);
//    }
//
//    /**
//     * Describe <code>map</code> method here.
//     *
//     * @param req a <code>ServletRequest</code> value
//     * @param loc a <code>Locale</code> value
//     * @return a <code>FormMap</code> value
//     */
//    public FormMap map(ServletRequest req, Locale loc) {
//        return super.map(req, prefix, loc);
//    }

    // implementation of org.barracudamvc.core.comp.Contextual interface

    /**
     * Describe <code>getItem</code> method here.
     *
     * @param key
     * @return <description>
     */
    public Object getItem(String key)
    {
        if(logger.isDebugEnabled()) {
            logger.debug("getItem() with key: " + key);
        }
        if(getElement(key) != null) {
            String name = prefix != null ? prefix + key: key;
            BComponent bc = null;
            FormElement el = getElement(key);
            if(el instanceof RepopulationElement) {
                Object res = ((RepopulationElement)el).render(getViewContext());
                if(!(res instanceof BComponent)) {
                    return res;
                }
                bc = (BComponent)res;
            }
            else {
                BInput bi = new BInput();
                if(logger.isDebugEnabled() && el.getOrigVal() != null) {
                    logger.debug("Class: " + el.getOrigVal().getClass() + " Value: " + el.getOrigVal());
                }
                bi.setValue((String)el.getOrigVal());
                bc = bi;
            }
            if(bc != null) {
                bc.setName(name);
                return bc;
            }
        }
        return super.getErrorComponent(key);
    }

    public Object getItem(TemplateDirective td) {
        return getItem(td.getKeyName());
    }

    /**
     *
     * @param vc <description>
     */
    public void setViewContext(ViewContext vc)
    {
        viewContext = vc;
    }

    /**
     *
     * @return <description>
     */
    public ViewContext getViewContext()
    {
        return viewContext;
    }
    // implementation of org.barracudamvc.core.comp.TemplateModel interface

    /**
     * Describe <code>getName</code> method here.
     *
     * @return <description>
     */
    public String getName()
    {
        return modelName;
    }


    /**
     * Describe <code>setName</code> method here.
     *
     * @param name a <code>String</code> value
     */
    public void setName(String name)
    {
        modelName = name;
    }

    /**
     *
     * @param td <description>
     * @return <description>
     */
    public boolean processDirective(TemplateDirective td)
    {
        // TODO: implement this org.barracudamvc.core.comp.TemplateModel method
        return true;
    }

    // implementation of org.barracudamvc.core.comp.model.Model interface

    /**
     *
     * @param ml <description>
     */
    public void addModelListener(ModelListener ml)
    {
        listeners.add(ml);
    }

    /**
     *
     * @param ml <description>
     */
    public void removeModelListener(ModelListener ml)
    {
        listeners.remove(ml);
    }

    /**
     * Forwards the given notification event to all
     * <code>TemplateModelListeners</code> that registered
     * themselves as listeners for this template model.
     */
    public void fireModelChanged() {
        Iterator it = listeners.iterator();
        ModelListener ml = null;
        while (it.hasNext()) {
            ml = (ModelListener) it.next();
            ml.modelChanged(this);
        }
    }

}
