/*
 * Copyright (C) 2003  Diez B. Roggisch [deets@web.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: DBRApplicationGateway.java 124 2005-12-28 06:03:02Z jkjome $
 */
package org.barracudamvc.contrib.dbroggisch.examples.controller;

import java.io.File;
import java.io.IOException;
import javax.servlet.http.HttpServletRequest;
import org.barracudamvc.core.event.ApplicationGateway;
import org.barracudamvc.core.event.DispatcherFactory;
import org.barracudamvc.core.helper.servlet.RequestWrapper;
import org.barracudamvc.core.helper.servlet.MultipartRequestWrapper;
import org.barracudamvc.contrib.dbroggisch.page.PageDispatcherFactory;
import org.barracudamvc.contrib.dbroggisch.page.RenderPageEventGateway;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.log4j.Logger;


public class DBRApplicationGateway extends ApplicationGateway {

    private static final Logger logger = Logger.getLogger(DBRApplicationGateway.class.getName());

    public void initializeLocal() {
        installWrapper();
        specifyEventGateways(new RenderPageEventGateway());

    }

    private void installWrapper() {
        String destDir = null;
        File tempDir = (File)getServletConfig().getServletContext().getAttribute("javax.servlet.context.tempdir");
        // Only if we have write permission to that directory we install the wrapper.
        if(tempDir.canWrite()) {
            REQUEST_WRAPPER = new SampleRequestWrapper(new DiskFileItemFactory(102400, tempDir));
        }
    }

    public static class SampleRequestWrapper implements RequestWrapper {
        DiskFileItemFactory _factory;
        public SampleRequestWrapper(DiskFileItemFactory factory) {
            _factory = factory;
        }

        public HttpServletRequest wrap(HttpServletRequest req) {
            return new MultipartRequestWrapper(req, _factory.getSizeThreshold() * 100, _factory);
        }
    }

//    public DispatcherFactory getDispatcherFactory() {
//        if (logger.isDebugEnabled()) logger.debug("instantiating SessionTreeStateDispatcherFactory");
//        return new SessionTreeStateDispatcher.DispatcherFactory();
//    }

    public DispatcherFactory getDispatcherFactory() {
        return new PageDispatcherFactory();
    }

}
