/*
 * Copyright (C) 2003  Diez B. Roggisch [deets@web.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: RepopulationHandler.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.contrib.dbroggisch.examples.controller.handlers;

import java.io.IOException;
import java.util.Iterator;
import java.util.Map;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import org.barracudamvc.core.event.ControlEventContext;
import org.barracudamvc.core.event.EventException;
import org.barracudamvc.core.forms.FormElement;
import org.barracudamvc.core.forms.ValidationException;
import org.barracudamvc.contrib.dbroggisch.page.Page;
import org.barracudamvc.contrib.dbroggisch.page.PageEventListener;
import org.apache.log4j.Logger;

import org.barracudamvc.contrib.dbroggisch.examples.model.forms.*;
import org.barracudamvc.contrib.dbroggisch.examples.view.pages.*;


public class RepopulationHandler extends PageEventListener {

    private static final Logger logger = Logger.getLogger(RepopulationHandler.class.getName());

    public void handleControlEvent(ControlEventContext context, Page p)
            throws EventException, ServletException, IOException {
        HttpServletRequest request = context.getRequest();
        ExampleFormMap cfm = new ExampleFormMap();
        RepopulationPage rPage = (RepopulationPage)p;
        rPage.setState(ExampleBasePage.REPOPULATION);

        // We put the form map into the page
        // so it can act as template model for
        // the rendering process.
        rPage.setRFM(cfm);

        // The request is only mapped and validated if a special hidden parameter is present.
        // I usually call it "visited". Be careful to assign a unique name to it, or you might
        // expirience strange errors when the application event flow is routed to a different event
        // handling form maps.
        if (ExampleFormMap.MODEL_NAME.equals(request.getParameter("visited"))) {
            try {
                // This is all you have to do - mapping and validation.
                cfm.map(request).validate(true);

                // Print all values the elements have.
                if (logger.isDebugEnabled()) {
                    Map els = cfm.getElements();

                    for (Iterator it = els.entrySet().iterator(); it.hasNext();) {
                        Map.Entry entry = (Map.Entry)it.next();
                        String name = (String)entry.getKey();
                        FormElement fel = (FormElement)entry.getValue();
                        logger.debug("Element " + name + ":");
                        Object val = fel.getVal();

                        if (val != null) {
                            logger.debug("Value class: " + val.getClass().getName());
                            logger.debug("Value: " + val);
                        } else {
                            logger.debug("Has a null-value");
                        }
                    }
                }
            } catch (ValidationException ex) {
                logger.debug("Form Validation Exception", ex);
            }
        }
        context.getEvent().setHandled(true);
        //context.getQueue().addEvent(new RenderRepopulation());
    }

}
