/*
 * Copyright (C) 2003  Diez B. Roggisch [deets@web.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PrefixmappingPage.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.contrib.dbroggisch.examples.view.pages;

import java.io.IOException;
import java.util.List;
import java.util.Locale;
import javax.servlet.ServletException;
import org.w3c.dom.Document;
//import org.enhydra.xml.xmlc.XMLCStdFactory;
import org.barracudamvc.core.comp.BAction;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BTemplate;
import org.barracudamvc.core.comp.BText;
import org.barracudamvc.core.comp.DefaultTemplateView;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.event.EventException;
import org.barracudamvc.core.util.dom.DefaultDOMLoader;
import org.barracudamvc.contrib.dbroggisch.display.HashMapModel;
import org.barracudamvc.contrib.dbroggisch.display.IterativeListModel;
import org.barracudamvc.contrib.dbroggisch.repopulation.RepopulationFormMap;
import org.apache.log4j.Logger;

import org.barracudamvc.contrib.dbroggisch.examples.controller.events.*;
import org.barracudamvc.contrib.dbroggisch.examples.model.forms.*;
import org.barracudamvc.contrib.dbroggisch.examples.view.xmlc.*;


public class PrefixmappingPage extends ExampleBasePage {

    private static final Logger logger = Logger.getLogger(PrefixmappingPage.class.getName());

    List _maps;

    public void setMaps(List maps) {
        _maps = maps;
    }

    public void render(BComponent root, ViewContext vec, Document pDoc)
            throws EventException, ServletException, IOException {
        super.render(root, vec, pDoc);
        Integer childCount = null;
        PrefixMappingHTML doc = (PrefixMappingHTML) pDoc;
        BTemplate mapComp = new BTemplate();

        mapComp.setView(new DefaultTemplateView(doc.getElementTestHook()));

        if(_maps.size() > 0) {
            // This is the parent form map
            RepopulationFormMap rfm = (RepopulationFormMap)_maps.remove(0);
            mapComp.addModel(rfm);
            childCount = (Integer)rfm.getVal(ParentFormMap.CHILD_COUNT);
        }

        IterativeListModel ilm = new IterativeListModel(ChildFormMap.MODEL_NAME, _maps) {
                public Object getItem(String key) {
                    return ((RepopulationFormMap)_current).getItem(key);
                }
            };

        mapComp.addModel(ilm);
        HashMapModel hmm = new HashMapModel();
        hmm.setName("ControlModel");
        hmm.setItem("SUBMIT", new BAction(new PrefixMapping()));
        hmm.setItem("ADD", new BAction(new PrefixMappingAddChild()));
        mapComp.addModel(hmm);

        HashMapModel foo = new HashMapModel();
        foo.setName("FooModel");
        foo.setItem(ParentFormMap.CHILD_COUNT, new BText(childCount == null ? "None" :
                                                         childCount.intValue() == 0 ? "None" :
                                                         "" + childCount.intValue()));

        mapComp.addModel(foo);
        root.addChild(mapComp);
    }

    public Document getDocument(Locale iLocale) {
        //return new XMLCStdFactory(null, null).create(PrefixMappingHTML.class);

        Document doc = null;
        //load the localized DOM template
        try {doc = DefaultDOMLoader.getGlobalInstance().getDOM(PrefixMappingHTML.class, iLocale);}
        catch (IOException ioe) {logger.fatal ("Fatal Error loading DOM template:", ioe);}
        return doc;
    }

}
