/*
 * Copyright (C) 2003  Stefan Armbruster [stefan@armbruster-it.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: DataObjectSaveHandler.java 124 2005-12-28 06:03:02Z jkjome $
 */
package org.barracudamvc.contrib.sam.data;

import gnu.regexp.RE;
import gnu.regexp.REMatch;

import java.util.Iterator;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import org.apache.commons.fileupload.FileItem;
import org.apache.log4j.Logger;
import org.barracudamvc.contrib.sam.models.ErrorModel;
import org.barracudamvc.contrib.sam.xmlform.XmlFormMap;
import org.barracudamvc.core.event.ControlEventContext;
import org.barracudamvc.core.event.DefaultBaseEventListener;
import org.barracudamvc.core.event.EventException;
import org.barracudamvc.core.forms.FormElement;
import org.barracudamvc.core.helper.servlet.MultipartRequestWrapper;

public abstract class DataObjectSaveHandler extends DefaultBaseEventListener implements GetConfig {

    protected static Logger logger = Logger.getLogger(DataObjectSaveHandler.class.getName());

    public abstract Config getConfig();

    protected Config config;
    protected XmlFormMap xfm;
    protected DataObject dataObj;

    public void handleControlEvent(ControlEventContext context) throws EventException, javax.servlet.ServletException, java.io.IOException {
        HttpServletRequest request = context.getRequest();
        config = getConfig();

        if (ErrorModel.exists(context)) return;
        logger.info("Saving DataObject");
        xfm = (XmlFormMap) context.getState(config.getMapName());
        try {
            // iterate over all form elements any change underlying dataobject
            String oid = xfm.getVal(config.getOidName()).toString();
            logger.info("oid is " + oid);
            dataObj = config.getDataObject(oid);
            Map elements = xfm.getElements();
            Iterator iter = elements.entrySet().iterator();
            while (iter.hasNext()) {
                Map.Entry e = (Map.Entry)iter.next();
                String key = (String)e.getKey();
                FormElement fe = (FormElement)e.getValue();
				if (logger.isDebugEnabled()) logger.debug("key " + key + " formelement " + fe.getClass().getName());
				
				Object oldData = fe.getVal();
				logger.debug("modify form data");
				Object newData = modifyFormData(key, oldData);
				logger.debug("pre-Set " + dataObj.getClass().getName());
				//logger.debug("old: " + oldData + " new: " + newData); // removed, due to OutOfMemory when large files are uploaded
                dataObj.set(key, newData);
                
                // if upload -> save also content type and fieldname
                if ((fe instanceof UploadLinkElement) && (request instanceof MultipartRequestWrapper)) {
                	logger.debug("upload form element detected");
                	MultipartRequestWrapper mpReq = (MultipartRequestWrapper)request;
                	UploadLinkElement ufe = (UploadLinkElement)fe;
					FileItem item = mpReq.getFileItem(ufe.getField());
                	if (item != null) {
                		dataObj.set(ufe.getContentTypeField(),item.getContentType());
                		String fileName = item.getName();
                		logger.info("filename " + fileName);
                		
                		// strip path part off
                		RE regex = new RE(".*[\\\\,\\/](.*)");
                		REMatch match = regex.getMatch(fileName);
                		if (match != null) {
                		    fileName = match.toString(1);  
                		}
                		logger.info("filename " + fileName);
						dataObj.set(ufe.getFileNameField(), fileName);
                	} else {
                		logger.warn("no FileItem for " + ufe.getField() + " found.");
                	}
                }
            }
            dataObj.save(null);
            if (logger.isDebugEnabled()) {
                logger.debug("oldoid is " + oid);
                String newoid = (String)dataObj.get(config.getOidName());
                logger.debug("newoid is " + newoid);
            }
                // sam, 2003-08-05 commented out next 4 lines, otherwise save&email fails (project cockpit...)
            // create a new formmap and store it in event's context for usage during rendering
            //xfm = new XmlFormMap(context, config.getXmlFormName(), config.getFormName(), dataObj);
                //logger.debug("oid from formmap:" + xfm.getStringVal(config.getOidName()));
            //context.putState(config.getMapName(), xfm);
            
        //} catch (DataObjectException ex) {
		} catch (Exception ex) {
            ErrorModel.create(context, ex);
            logger.error(ex.getMessage(),ex);
        }
    }

    /**
     * gives subclasses a hook to change the form data before it is saved
     */
    protected Object modifyFormData(String key, Object value) {
        return value;
    }
}
