/*
 * Copyright (C) 2003  Stefan Armbruster [stefan@armbruster-it.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: ErrorModel.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.contrib.sam.models;

import java.util.List;
import java.util.Vector;

import org.apache.log4j.Logger;
import org.barracudamvc.contrib.dbroggisch.display.IterativeCollectionModel;
import org.barracudamvc.core.comp.TemplateDirective;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.event.EventContext;
import org.barracudamvc.core.forms.ValidationException;

/** ErrorModel is a special Model for displaying form validation errors.
 * During the control events, the model if filled by calling the static {@link
 * #create } methods with the form validation exceptions<br>
 * During the view phase, the model acts as a IterativeModel and displays the error
 * messages.
 */
public class ErrorModel extends IterativeCollectionModel {

    protected static Logger logger = Logger.getLogger(ErrorModel.class.getName());

    public static final String DEFAULT_ERRORMODEL = "Error";
    public static final String DIRECTIVE_VISIBLE = "Has_Errors";

    public ErrorModel(ViewContext vc) {
        this(DEFAULT_ERRORMODEL, vc);
    }

    public ErrorModel(String name, ViewContext vc) {
        super(name);
        List errorList = (List)vc.getEventContext().getState(name);
        if (logger.isDebugEnabled()) logger.debug("retrieving exception list from event context: " + errorList);
        if (errorList == null) errorList = new Vector();
        if (logger.isDebugEnabled()) logger.debug("errorlist has " + errorList.size() + " items.");
        setModels(errorList);
    }

    public Object getItem(String key) {
        if (logger.isDebugEnabled()) {
            if (_current== null) {
                logger.error("_current is null");
            } else {
                logger.debug("_current: " + _current + _current.getClass().getName());
            }
        }
        return ((Exception)_current).getMessage();
    }

    public boolean processDirective(TemplateDirective td) {
        if (td.getCommand().equals(DIRECTIVE_VISIBLE) && (getModels().size()==0)) return false;
        return true;
    }

    /*public static void create(EventContext context, ValidationException ex) {
        create(DEFAULT_ERRORMODEL, context, ex);
    }

    public static void create(String name, EventContext context, ValidationException ex) {
        if (logger.isDebugEnabled()) logger.debug("Storing exception list to event context");
        List l = ex.getExceptionList();
        context.putState(name, l);
    }*/

    public static void create(EventContext context, Exception ex) {
        create(DEFAULT_ERRORMODEL, context, ex);
    }

    public static void create(String name, EventContext context, Exception ex) {
        if (logger.isDebugEnabled()) logger.debug("Storing single exception to event context");
            List l;
          if (ex instanceof ValidationException) {
           l = ((ValidationException)ex).getExceptionList();
            } else {
                l = (List)context.getState(name);
                if (l==null) l = new Vector();
                l.add(ex);
            }
        context.putState(name, l);
    }

    public static void remove(EventContext context) {
        remove(DEFAULT_ERRORMODEL, context);
    }

    public static void remove(String name, EventContext context) {
        context.removeState(name);
    }

    public static boolean exists(EventContext context) {
        return exists(DEFAULT_ERRORMODEL, context);
    }

    public static boolean exists(String name, EventContext context) {
        return (context.getState(name) != null);
    }
}


