/*
 * HTMLLabelRenderer.java
 *
 * Created on 16 novembre 2004, 17:26
 * Copyright (c) 2004 mecadu.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.barracudamvc.core.comp.renderer.html;

import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.NoSuitableRendererException;
import org.barracudamvc.core.comp.RenderException;
import org.barracudamvc.core.comp.UnsupportedFormatException;
import org.barracudamvc.core.comp.View;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.renderer.html.HTMLComponentRenderer;
import org.barracudamvc.core.util.dom.DOMUtil;
import org.barracudamvc.core.comp.BLabel;
import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.Text;
import org.w3c.dom.html.HTMLLabelElement;

/**
 * This class handles the default rendering of label into an HTML view.
 */
public class HTMLLabelRenderer extends HTMLComponentRenderer {

    protected static final Logger log = Logger.getLogger(HTMLLabelRenderer.class.getName());

    
    public Node createDefaultNode(Document doc, BComponent comp, ViewContext vc) throws UnsupportedFormatException {

    	Node defaultNode = null;
    	
    	if (vc.getTemplateNode() instanceof HTMLLabelElement) {
            defaultNode = super.createDefaultNode(doc, comp, vc);
        } else {
        	defaultNode = doc.createElement("LABEL");
        }
        return defaultNode;
    }

    /**
     * 
     */
    public void renderComponent(BComponent comp, View view, ViewContext vc) throws RenderException {
        //make sure the component is a label component
        if (!(comp instanceof BLabel)) throw new NoSuitableRendererException("This renderer can only render BLabel components");

        //show what we're doing
        //showNodeInterfaces(view, logger);

        //first, allow the parent class to do anything it needs to
        super.renderComponent(comp, view, vc);

        BLabel blabel = (BLabel) comp;
        String text = blabel.getText();
        String id = blabel.getForId();
        
        Node node = view.getNode();
        
        //HTMLElement Interface
        //---------------------
        //Supported Elements:
        //..HTMLLabelElement
        if (node instanceof HTMLLabelElement) {
            if (log.isInfoEnabled()) log.info("Rendering based on HTMLLabelElement interface...");
            ((HTMLLabelElement) node).setHtmlFor(id);
            Node newNode = node.getOwnerDocument().createTextNode(text);
            Node firstChild = node.getFirstChild();
            if (firstChild instanceof Text) {
            	node.replaceChild(newNode, firstChild);
            }
            else {
            	node.insertBefore(newNode, firstChild);
            }
        } else {
            String errmsg = "Node does not implement HTMLLabelElement and cannot be rendered: "+node;
            log.warn(errmsg);
            throw new NoSuitableRendererException(errmsg);
        }
    }
}
