/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: HTMLScriptRenderer.java 159 2007-02-04 17:17:18Z alci $
 */
package org.barracudamvc.core.comp.renderer.html;

import java.util.Iterator;
import java.util.List;

import org.apache.log4j.Logger;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BScript;
import org.barracudamvc.core.comp.BScriptResource;
import org.barracudamvc.core.comp.DefaultView;
import org.barracudamvc.core.comp.NoSuitableRendererException;
import org.barracudamvc.core.comp.RenderException;
import org.barracudamvc.core.comp.UnsupportedFormatException;
import org.barracudamvc.core.comp.View;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.renderer.DOMComponentRenderer;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * This class handles the default rendering script references into an HTML view.
 */
public class HTMLScriptRenderer extends DOMComponentRenderer {

    protected static final Logger logger = Logger.getLogger(HTMLScriptRenderer.class.getName());


    public Node createDefaultNode(Document doc, BComponent comp, ViewContext vc) throws UnsupportedFormatException {
    	return null; // returning null will bind the BScript to the parent view
    }
    /**
     *
     */
    public void renderComponent(BComponent comp, View view, ViewContext vc) throws RenderException {
        //unlike other components, this one really doesn't care what we're bound
        //to...we do need to make sure the component is a script component
        if (!(comp instanceof BScript)) throw new NoSuitableRendererException("This renderer can only render BScript components");

        //show what we're doing
        showNodeInterfaces(view, logger);
        
        //now allow the parent class to do anything it needs to
        super.renderComponent(comp, view, vc);
        
        BScript bsComp = (BScript) comp;
        Node node = view.getNode();

        //sanity checks
        String jsattr = bsComp.getJSAttr();
        String jscmd = bsComp.getCmd();
        
//      Shortcircuit rendering if no src to set
        if (jsattr==null || jscmd==null || !(node instanceof Element)) {
        	logger.warn("Null jsattr, jscmd, or bound node not an Element, skipping rendering.");
        	return;
        }
        
        int mode = bsComp.getMode();
        Element el = (Element) node;


        //note that we always want to render this script...this way if the client
        //has scripting disabled now, but re-enables it later, we will know about it
        //the next time around. If they don't have scripting enabled this can't hurt.

        //render the component
        if (!jscmd.endsWith(";")) jscmd = jscmd + "; ";
        String cur_attr = el.getAttribute(jsattr);
        if (cur_attr==null) mode = BScript.REPLACE;
        //...append
        if (mode==BScript.APPEND) {
            if (!cur_attr.endsWith(";")) cur_attr = cur_attr + "; ";
            el.setAttribute(jsattr, cur_attr+jscmd);
        //...prepend
        } else if (mode==BScript.PREPEND) {
            el.setAttribute(jsattr, jscmd+cur_attr);
        //...replace
        } else {
            el.setAttribute(jsattr, jscmd);
        }
        
        //add in BScriptResource components that are needed
        List resources = bsComp.getResources();
        if (resources!=null) {
            Iterator it = resources.iterator();
            while (it.hasNext()) {
                String scr = (String) it.next();
                BScriptResource bsr = new BScriptResource(scr);
                bsr.setView(new DefaultView(node));
                bsComp.addStepChild(bsr, true);
            }
        }
    }
}