/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: ValidTypeValidator.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.core.forms.validators;

import org.barracudamvc.core.forms.DefaultFormValidator;
import org.barracudamvc.core.forms.FormElement;
import org.barracudamvc.core.forms.FormType;
import org.barracudamvc.core.forms.ValidationException;

/**
 * This validator ensures that the original value constitues a
 * valid type
 */
public class ValidTypeValidator extends DefaultFormValidator {

    /**
     * Public constructor.
     */
    public ValidTypeValidator() {
        super();
    }

    /**
     * Public constructor.
     *
     * @param ierrorMessage the message associated with this error
     */
    public ValidTypeValidator(String ierrorMessage) {
        super(ierrorMessage);
    }

    /**
     * Public constructor.
     *
     * @param errorMessage the message associated with this error
     * @param deferExceptions true if want generated exceptions to be deferred
     */
//    public ValidTypeValidator(String ierrorMessage, boolean ideferExceptions) {
//        super(ierrorMessage, ideferExceptions);
//    }

    /**
     * Validate a FormElement to make sure that the non-null orig values are valid
     * for the specified element type
     *
     * @param val the value to compare the element value to
     * @param element the form element that contains the val
     *        to validate elements by comparing them with other elements)
     * @param deferExceptions do we want to deferValidation exceptions
     *        and attempt to validate all elements so that we can process
     *        all the exceptions at once
     * @throws ValidationException if the element is not valid
     */
    public void validateFormElement(Object val, FormElement element, boolean deferExceptions) throws ValidationException {
        //ilc-02-20-2000 begin changes
        //make sure we validate val
//        Object origVal = element.getOrigVal();
        //ilc-02-20-2000 end changes
        FormType ft = element.getType();
        if (localLogger.isInfoEnabled()) localLogger.info("validating orig val="+val+" is of type:"+ft);
//System.out.println("validating orig val="+origVal+" is of type:"+ft);

        //ilc-02-20-2000 begin changes
        //Do not make judgement calls on null and empty strings
//        if (origVal==null) return;    //this validator makes no judgement calls if the value is null
        //this validator makes no judgement calls if the value is null
        // if (val==null || val.toString().trim().length()<1) return;
        if (isNull(val, element))
          return;
        //ilc-02-20-2000 end changes

        if (element.getParseException()!=null) {
            throw this.generateException(element, deferExceptions, "Invalid value '"+val+"' for form type "+ft);
        }
    }

}
