/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: LoginServices.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.examples.ex1;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.barracudamvc.core.event.EventException;
import org.barracudamvc.plankton.http.SessionServices;

/**
 * This class provides basic Login services, specifically:
 * - validateUserPwd (either from HttpReq, HttpSession,
 *   or based on a specific user/pwd combo)
 */
public class LoginServices {

    //session constants used throughout the app
    public static final String NUMBER_OF_VISITS = LoginServices.class.getName()+".NumberOfVisits";    //int
    public static final String AUTO_LOGIN = LoginServices.class.getName()+".AutoLogin";                //boolean
    public static final String USER = "User";            //String
    public static final String PASSWORD = "Password";    //String

    //validateUserPwd results
    public static final int VALID = 0;
    public static final int INVALID_USER = 1;
    public static final int INVALID_PASSWORD = 2;
    public static final int INVALID_DATA_MISSING = 3;
    public static final int INVALID_SESSION_EXPIRED = 4;
    public static final int INVALID_OTHER = 99;

    /**
     * Convert validation results into text
     */
    public static String xrefValidity(int valid) {
        if (valid==VALID) return "VALID";
        else if (valid==INVALID_USER) return "INVALID_USER";
        else if (valid==INVALID_PASSWORD) return "INVALID_PASSWORD";
        else if (valid==INVALID_DATA_MISSING) return "INVALID_DATA_MISSING";
        else if (valid==INVALID_SESSION_EXPIRED) return "INVALID_SESSION_EXPIRED";
        else if (valid==INVALID_OTHER) return "INVALID_OTHER";
        else return "???";
    }

    /**
     * Validate user/pwd, getting the information from the
     * HttpServletRequest object
     */
    public static int validateUserPwd(HttpServletRequest req, boolean updateSession) throws EventException {
        //get the login information from the request
        String user = req.getParameter(USER);
        String password = req.getParameter(PASSWORD);

        //update this info in the session if requested
        if (updateSession) {
            HttpSession session = SessionServices.getSession(req);
            session.setAttribute(USER, ""+user);
            session.setAttribute(PASSWORD, ""+password);
        }

        //this is kind of a hokey little way to catch our exception (which is just
        //for demo purposes anyway) and clean up after ourselves by removing the
        //user info fromt he session, so the error does not continue indefinitely)
        int result = INVALID_OTHER;
        try {result = validateUserPwd(user, password);}
        catch (WhoYouCallingKlausException e) {
            if (updateSession) {
                HttpSession session = SessionServices.getSession(req);
                session.setAttribute(USER, null);
                session.setAttribute(PASSWORD, null);
            }
            throw e;
        }
        return result;
    }

    /**
     * Validate user/pwd, getting the information from the
     * HttpSession object
     */
    public static int validateUserPwd(HttpSession session) throws EventException {
        //make sure the session hasn't expired


        //get the login information from the request
        String user = (String) session.getAttribute(USER);
        String password = (String) session.getAttribute(PASSWORD);
        return validateUserPwd(user, password);
    }

    /**
     * Validate user/pwd
     */
    public static int validateUserPwd(String user, String password) throws EventException {
        //make sure the data is there
        if (user==null || password==null) return INVALID_DATA_MISSING;

        //validate the login information
        if (user.equals("santa")) return INVALID_OTHER;
        if (user.equals("klaus")) throw new WhoYouCallingKlausException();
        if (!user.equals("foo")) return INVALID_USER;
        if (!password.equals("bar")) return INVALID_PASSWORD;

        //it's ok!
        return VALID;

    }

    static class WhoYouCallingKlausException extends EventException {
        public WhoYouCallingKlausException() {
            super ("Hey, who are you calling Klaus!!!");
        }
    };

}
