package org.barracudamvc.examples.xmlc;

import javax.servlet.http.HttpServletRequest;

import org.barracudamvc.core.comp.AbstractBlockIterator;
import org.barracudamvc.core.comp.AbstractIterativeTemplateModel;
import org.barracudamvc.core.comp.BlockIterator;
import org.barracudamvc.core.comp.IterativeModel;
import org.barracudamvc.core.comp.TemplateDirective;
import org.barracudamvc.core.comp.TemplateModel;
import org.barracudamvc.core.comp.helper.BTemplateGateway;
import org.barracudamvc.core.event.ApplicationGateway;
import org.barracudamvc.core.util.dom.DOMWriter;
import org.barracudamvc.core.util.dom.DefaultDOMWriter;
import org.barracudamvc.plankton.data.ObjectRepository;

/**
 * Make sure a reusable component can handle nested images within an anchor element
 */
public class CompEx10 extends BTemplateGateway {

    public static int NUMBER_OF_ROWS = 5;

    //-------------------- BTemplateGateway ----------------------
    /**
     * Return an instance of the template model
     */
    public TemplateModel getTemplateModel() {
        return new LocalModel();
    }
    
    /**
     * Return an instance of the template class (must implement Document)
     */
    public Class getTemplateClass() {
        ObjectRepository lor = ObjectRepository.getLocalRepository();
        HttpServletRequest req = (HttpServletRequest) lor.getState(ApplicationGateway.HTTP_SERVLET_REQUEST);
        boolean useBlockIterator = (req.getParameter("$usebi")!=null);    
        return (useBlockIterator ? CompEx10aHTML.class : CompEx10HTML.class);
    }
    
    public DOMWriter getDOMWriter() {
        return new DefaultDOMWriter();
    }
    
    //provide a block iterator - only necessary if part of the template needs to be streamed back directly
    public BlockIterator getIterator(String key) {
        return new AbstractBlockIterator() {
            LocalModel lm = new LocalModel();   //this block iterator will use one model repeatedly, and delegate to it as needed
            
            public boolean hasNext() {return lm.hasNext();}
            
            public boolean loadNext() {
                return true;
            }
            
            public Object getTemplateModels() {return lm;}
        };
    }
    

    //--------------- TemplateModel --------------------------
    /**
     * LocalModel
     */
    class LocalModel extends AbstractIterativeTemplateModel {
        int row = -1;
        int col = -1;

        //register the model by name
        public String getName() {return "Ex10Model";}
        
        //provide items by key
        public Object getItem(TemplateDirective td) {
            String key = td.getKeyName();
            if (key.equals("RowNumber")) {
                return "Row "+row;

            } else if (key.equals("SampleData")) {
                col++;
                return "{"+col+"}";

            } else {
                return super.getItem(td);
            }
        }

        //does the model have more items in the list?
        public boolean hasNext() {
            return (row<NUMBER_OF_ROWS);
        }

        //move to the next position in the list      
        public void loadNext() {
            row++;
            col = -1;
        }
        
        public void preIterate() {
            System.out.println("preIterate");        
        }
        public void postIterate() {
            row = -1;
            col = -1;
            System.out.println("postIterate");        
        }        
    }
    
    //hook for CompEx11 to use this model
    public IterativeModel getLocalModel() {
        return new LocalModel();
    }
}
