package org.barracudamvc.examples.xmlc;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.barracudamvc.core.comp.AbstractTableModel;
import org.barracudamvc.core.comp.AbstractTemplateModel;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BImage;
import org.barracudamvc.core.comp.BInput;
import org.barracudamvc.core.comp.BLabel;
import org.barracudamvc.core.comp.BLink;
import org.barracudamvc.core.comp.BList;
import org.barracudamvc.core.comp.BScript;
import org.barracudamvc.core.comp.BSelect;
import org.barracudamvc.core.comp.BTable;
import org.barracudamvc.core.comp.BTemplate;
import org.barracudamvc.core.comp.BText;
import org.barracudamvc.core.comp.BToggleButton;
import org.barracudamvc.core.comp.DefaultItemMap;
import org.barracudamvc.core.comp.DefaultListModel;
import org.barracudamvc.core.comp.DefaultTableView;
import org.barracudamvc.core.comp.DefaultTemplateView;
import org.barracudamvc.core.comp.DefaultView;
import org.barracudamvc.core.comp.ListModel;
import org.barracudamvc.core.comp.TableModel;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.helper.ComponentGateway;
import org.barracudamvc.core.util.dom.DOMWriter;
import org.barracudamvc.core.util.dom.DefaultDOMLoader;
import org.barracudamvc.core.util.dom.DefaultDOMWriter;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * Here's an example of how the component stuff can be implemented
 * in a standalone servlet.
 */
public class CompEx11 extends ComponentGateway {

    //-------------------- ComponentGateway ----------------------
    /**
     * Handle the default HttpRequest. 
     */
    public Document handleDefault(BComponent root, ViewContext vc, HttpServletRequest req, HttpServletResponse resp) throws IOException {
        //load the localized DOM template
        Document page = DefaultDOMLoader.getGlobalInstance().getDOM(CompEx11HTML.class);
        Node n = null;

        //manually bind a nested component to the view
        n = page.getElementById("SimpleManualID");
//     	DeepNestedComponent nested = new DeepNestedComponent("manualId");
    	BScript script = new BScript(BScript.ON_CLICK,"alert(\'This script works\')");
	  	BImage img = new BImage("Alt text", "Title text", "images/imagemap.gif", "12", "12");
	  	img.addChild(script);
	  	BInput input = new BInput(BInput.TEXT,"Input ","Default Value ");
	  	BLabel nested = new BLabel("Manual binding","Manual");
	  	nested.addChild(input);
	  	nested.addChild(img);
    	nested.setView(new DefaultView(n));
    	nested.setAttr("id","TestManualLabel");
    	root.addChild(nested);
        
        //create a template component and bind it to the views
        n = page.getElementById("SimpleTemplateID"); 
        if (n!=null) {
            BTemplate templateComp = new BTemplate(new SimpleTemplateModel());
            templateComp.setView(new DefaultTemplateView(n));
            root.addChild(templateComp);
        }

        //create a list component and bind it to the view
        // Has with BList, binding a nested component to multiple view
        // is problematic... see comments from Christian below, taken in BList CompEx5 test

        n = page.getElementById("SimpleListID");
        if (n!= null) {
        	BList blist = new BList();
        	blist.setName("BList 1");
        	DefaultListModel dlm = new DefaultListModel();
        	blist.setModel(dlm);
        	BalancedNestedComponent balanced = new BalancedNestedComponent("balListId");
        	balanced.setAttr("id","TestListLabel");
        	dlm.add(balanced);
        	blist.addView(new DefaultView(n));
        	root.addChild(blist);
        }
        n = page.getElementById("SimpleTableID");
        if (n != null) {
        	BTable btable = new BTable();
        	btable.setName("BTable 1");
        	TableModel tm = new SimpleTableModel();
        	btable.setModel(tm);
        	btable.addView(new DefaultTableView(n));
        	root.addChild(btable);
        }

        //return the page
        return page;
    }

    /**
     * <p>Get a DOMWriter. By default, we use a DefaultDOMWriter. If
     * you'd like to use something else, override this method.
     *
     * @return a DOMWriter to be used to render the DOM
     */
    public DOMWriter getDOMWriter() {
        //return DefaultDOM writer
        return new DefaultDOMWriter(true);
//        return new DefaultDOMWriter(false);
    }

    //-------------------------------------
    /**
     * SimpleTemplateModel
     */
    class SimpleTemplateModel extends AbstractTemplateModel {
        //register the model by name
        public String getName() {
            return "Test1";
        }
        
        //provide items by key
        public Object getItem(String key) {
            ViewContext vc = getViewContext();
            if (key.equals("ImageAndScript")) {
                BScript script = new BScript(BScript.ON_CLICK,"alert(\'This script works\')");
                BImage img = new BImage("This image has a script", "images/imagemap.gif", "12", "12");
                img.addChild(script);
                return img;
            } else if (key.equals("LabelAndToggle")) {
                BToggleButton toggle = new BToggleButton(BInput.CHECKBOX,
                		"ToggleButtonName","T",true);
                return new BLabel("Label for checkbox ", toggle);
            } else if (key.equals("LabelInputAndImage")) {
        	  	BImage img = new BImage("Alt text", "Title text", "images/imagemap.gif", "12", "12");
        	  	BInput input = new BInput(BInput.TEXT,"Input name","Default Value");
        	  	input.addChild(img);
        	  	return new BLabel("Label for input ", input);
          } else if (key.equals("LabelInputImageAndScript")) {
        	  	DeepNestedComponent deep = new DeepNestedComponent("deep");
        	  	deep.setAttr("id","TestTemplateDeepLabel");
        	  	return deep;
          } else if (key.equals("LabelInputAndImageScript")) {
        	  BalancedNestedComponent balanced = new BalancedNestedComponent("balanced");
        	  balanced.setAttr("id","TestTemplateLabel");
        	  return balanced;
          }
          else return super.getItem(key);
        }
    }
    
    
    //--------------- Table Model ----------------------------
    class SimpleTableModel extends AbstractTableModel {
        public Object getItemAt(int row, int col) {
            ViewContext vc = getViewContext();
            if (col==0) {
                return "Row "+(row+1);
            } else if (col==1 && row==2) {
            	BalancedNestedComponent balanced = new BalancedNestedComponent("tabBalanced");
          	    balanced.setAttr("id","TestTableLabel");
          	    return balanced;
            } else {
                return null;
            }    
        }

        public int getRowCount() {return 3;}
        public int getColumnCount() {return 2;}
    }
    
    class DeepNestedComponent extends BLabel {
    	public DeepNestedComponent(String tagId){
    		// This nested component is 4 level deep
    		// Label<Input<Image<Script
    		super("Label for id "+tagId, tagId);
    	  	BScript script = new BScript(BScript.ON_CLICK,"alert(\'This script works ("+tagId+")\')");
    	  	BImage img = new BImage("Alt text"+tagId, "Title text"+tagId, "images/imagemap.gif", "12", "12");
    	  	img.addChild(script);
    	  	BInput input = new BInput(BInput.TEXT,"Input "+tagId,"Default Value "+tagId);
    	  	input.addChild(img);
    	  	this.addChild(input);
    	}
    }
    
    class BalancedNestedComponent extends BLabel {
    	public BalancedNestedComponent(String tagId){
    		// This nested component is 3 level deep but has two branches
    		// Label<Input
    		//      <Image<Script
    		super("Label for id "+tagId, tagId);
    	  	BScript script = new BScript(BScript.ON_CLICK,"alert(\'This script works ("+tagId+")\')");
    	  	BImage img = new BImage("Alt text"+tagId, "Title text"+tagId, "images/imagemap.gif", "12", "12");
    	  	img.addChild(script);
    	  	BInput input = new BInput(BInput.TEXT,"Input "+tagId,"Default Value "+tagId);
    	  	this.addChild(input);
    	  	this.addChild(img);
    	}
    }
}
