package org.barracudamvc.examples.xmlc;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.barracudamvc.core.comp.AbstractTableModel;
import org.barracudamvc.core.comp.AbstractTemplateModel;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BInput;
import org.barracudamvc.core.comp.BLink;
import org.barracudamvc.core.comp.BList;
import org.barracudamvc.core.comp.BSelect;
import org.barracudamvc.core.comp.BTable;
import org.barracudamvc.core.comp.BTemplate;
import org.barracudamvc.core.comp.BText;
import org.barracudamvc.core.comp.BToggleButton;
import org.barracudamvc.core.comp.DefaultItemMap;
import org.barracudamvc.core.comp.DefaultListModel;
import org.barracudamvc.core.comp.DefaultTableView;
import org.barracudamvc.core.comp.DefaultTemplateView;
import org.barracudamvc.core.comp.DefaultView;
import org.barracudamvc.core.comp.ListModel;
import org.barracudamvc.core.comp.TableModel;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.helper.ComponentGateway;
import org.barracudamvc.core.util.dom.DOMWriter;
import org.barracudamvc.core.util.dom.DefaultDOMLoader;
import org.barracudamvc.core.util.dom.DefaultDOMWriter;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * Here's an example of how the component stuff can be implemented
 * in a standalone servlet.
 */
public class FindRendererBugTest extends ComponentGateway {

    //-------------------- ComponentGateway ----------------------
    /**
     * This class will generate a NPE if renderer.
     * 
     *  The scenario is :
     *
     * 1) extend a component : see Mytext inner class
     * 2) manually bind an instance of it to a node
     * 3) also return another instance from, say, BTemplate
     *
     * Render all this and you get the following exception :
     *
     * java.lang.NullPointerException
     *       at org.barracudamvc.core.comp.AbstractBComponent.findRendererFactory(AbstractBComponent.java:225)
     *       at org.barracudamvc.core.comp.AbstractBComponent.getRenderer(AbstractBComponent.java:195)
     *       at org.barracudamvc.core.comp.renderer.TemplateHelper.getNode(TemplateHelper.java:401)
     *       at org.barracudamvc.core.comp.renderer.TemplateHelper.copyChildNodes(TemplateHelper.java:153)
     *       at org.barracudamvc.core.comp.renderer.TemplateHelper.getNode(TemplateHelper.java:836)
     *       at org.barracudamvc.core.comp.renderer.TemplateHelper.copyChildNodes(TemplateHelper.java:153)
     * I think it has something to do with the fact that RendererFactory class and registration are static, and rfDomMap in AbstractBComponent also is static, but I must admit I can't fully explain what is happening. 
     */
    public Document handleDefault(BComponent root, ViewContext vc, HttpServletRequest req, HttpServletResponse resp) throws IOException {
        //load the localized DOM template
        Document page = DefaultDOMLoader.getGlobalInstance().getDOM(FindRendererBugTestHTML.class);
        Node n = null;

        n = page.getElementById("Manual");
        Mytext text = new Mytext();
        text.addView(new DefaultView(n));
        root.addChild(text);
        
        //create a template component and bind it to the views
        n = page.getElementById("Template"); 
        if (n!=null) {
            BTemplate templateComp = new BTemplate(new SimpleTemplateModel());
            templateComp.setView(new DefaultTemplateView(n));
            root.addChild(templateComp);
        }
        
        //return the page
        return page;
    }

    /**
     * <p>Get a DOMWriter. By default, we use a DefaultDOMWriter. If
     * you'd like to use something else, override this method.
     *
     * @return a DOMWriter to be used to render the DOM
     */
    public DOMWriter getDOMWriter() {
        //return DefaultDOM writer
        return new DefaultDOMWriter(true);
//        return new DefaultDOMWriter(false);
    }

    //---------------  ------------------------
    /**
     * SimpleTemplateModel
     */
    class SimpleTemplateModel extends AbstractTemplateModel {
        //register the model by name
        public String getName() {
            return "Test";
        }
        
        //provide items by key
        public Object getItem(String key) {
            ViewContext vc = getViewContext();
            if (key.equals("Mytext")) {
                return new Mytext();
            } else return super.getItem(key);
        }
    }

    class Mytext extends BText {
    	public Mytext() {
    		super("A sample text");
    	}
    }
}
