/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestBTextRender.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.core.comp;

import java.io.*;
import org.w3c.dom.*;
import org.barracudamvc.core.util.dom.*;
import org.apache.log4j.*;
import org.barracudamvc.core.view.*;
import org.barracudamvc.examples.xmlc.*;
import org.barracudamvc.testbed.*;
import org.barracudamvc.testbed.servlet.*;


/**
 * This test verifies that BText works correctly.
 */
public class TestBTextRender extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestBTextRender.class.getName();
    private static Logger logger = Logger.getLogger("test."+testClass);

    //variables
    
    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestBTextRender(String name) {
        super(name);
    }

    /**
     * Every test class should have a main method so it can be run 
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }

    
    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!
    
    /**
     * Simple test to verify that the component renders as expected
     */
    public void testBTextRender() throws IOException, RenderException {
        //render the doc
        if (logger.isInfoEnabled()) logger.info("testing BText render");
        CompEx7 cg = new CompEx7();
        BComponent root = new BComponent();
        root.initCycle();

        //build a sample view capabilities object
        MockHttpServletRequest req = new MockHttpServletRequest();
        req.setHeader("User-Agent","Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
        ViewCapabilities vcap = new ViewCapabilities(req, null);
//System.out.println(vcap.toString());        

        //create the component amd render
        DefaultViewContext vc = new DefaultViewContext(vcap, req, null);
        Document doc = cg.handleDefault(root, vc, req, null);
        vc.setDocument(doc);                                   //csc_072604_2
        root.render(vc);
        root.destroyCycle();
        DefaultDOMWriter ddw = new DefaultDOMWriter(false);
//        ddw.write(doc, System.out);
        StringWriter sw = new StringWriter(2000);
        ddw.write(doc, sw);
        String html = sw.toString();
//System.out.println("html:"+html);

        //assert that the text got rendered as we expected
        int fpos = html.indexOf("Text1: &lt;strong&gt;bold&lt;/strong&gt;");
        assertTrue("BText render err1", fpos>0);
        fpos = html.indexOf("&lt;em&gt;zing1&lt;/em&gt;");
        assertTrue("BText render err2", fpos>0);
        fpos = html.indexOf("Text2: <strong>bold</strong>");
        assertTrue("BText render err3", fpos>0);
        fpos = html.indexOf("<em>zing2</em>");
        assertTrue("BText render err4", fpos>0);
        //...make sure custom attrs are retained
        fpos = html.indexOf("customattr1");
        assertTrue("BText render err5.1", fpos>0);
        fpos = html.indexOf("customattr2");
        assertTrue("BText render err5.2", fpos>0);
        fpos = html.indexOf("customattr3");
        assertTrue("BText render err5.3", fpos>0);
        fpos = html.indexOf("customattr4");
        assertTrue("BText render err5.4", fpos>0);
    }
}
