/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestCompCreate.java 159 2007-02-04 17:17:18Z alci $
 */
package org.barracudamvc.core.comp;

import org.barracudamvc.testbed.*;


/**
 * This test verifies that components get created correctly
 */
public class TestCompCreate extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestCompCreate.class.getName();

    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestCompCreate(String name) {
        super(name);
    }

    /**
     * Every test class should have a main method so it can be run 
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }

    
    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!
    
    /**
     * Simple test to make sure BComponents are instantiated correctly
     */
    public void testBComponentCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BComponent comp = new BComponent();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BText are instantiated correctly
     */
    public void testBTextCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BText comp = new BText();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BAction are instantiated correctly
     */
    public void testBActionCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BAction comp = new BAction();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BLink are instantiated correctly
     */
    public void testBLinkCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BLink comp = new BLink();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BInput are instantiated correctly
     */
    public void testBInputCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BInput comp = new BInput();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BToggleButton are instantiated correctly
     */
    public void testBToggleButtonCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BToggleButton comp = new BToggleButton();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BTemplate are instantiated correctly
     */
    public void testBTemplateCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BTemplate comp = new BTemplate();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BTable are instantiated correctly
     */
    public void testBTableCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BTable comp = new BTable();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BList are instantiated correctly
     */
    public void testBListCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BList comp = new BList();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BSelect are instantiated correctly
     */
    public void testBSelectCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BSelect comp = new BSelect();
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    // fro_020407_begin add tests for BLabel and BImage
    /**
     * Simple test to make sure BImage are instantiated correctly
     */
    public void testBImageCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BImage comp = new BImage("Alt text","images/imagemap.gif");
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    
    /**
     * Simple test to make sure BLabel are instantiated correctly
     */
    public void testBLabelCreate() {
        //make sure we can instantiate (ie. that its never declared abstract)
        BLabel comp = new BLabel("Label","forId");
    
        //ensure that the basic characteristics are as we expect
        performGeneralChecks(comp);
    }
    // fro_020407_end
    
    protected void performGeneralChecks(BComponent comp) {
        //make sure that a newly created component never has a name set. This is 
        //important, because if we ever start defaulting the name then it will
        //automatically set the name attribute in views (see the HTMLComponentRenderer
        //for details). The name attribute should only get set when the name is 
        //specifically set.
        assertNull("Default component name not null", comp.getName());
    }
}
