/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestBLinkRender.java 114 2005-12-09 15:51:51 +0000 (ven., 09 déc. 2005) christianc $
 */
package org.barracudamvc.core.comp;

import java.io.*;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import org.barracudamvc.core.util.dom.*;
import org.apache.log4j.*;
import org.barracudamvc.core.view.*;
import org.barracudamvc.examples.xmlc.*;
import org.barracudamvc.testbed.*;
import org.barracudamvc.testbed.servlet.*;


/**
 * This test verifies that nested components works correctly.
 */
public class TestNestedRender extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestNestedRender.class.getName();
    private static Logger logger = Logger.getLogger("test."+testClass);

    //variables
    
    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestNestedRender(String name) {
        super(name);
    }

    /**
     * Every test class should have a main method so it can be run 
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }

    
    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!
    
    /**
     * Simple test to verify that the component renders as expected
     */
    public void testNestedRender() throws IOException, RenderException {

        //render the doc
        if (logger.isInfoEnabled()) logger.info("testing Nested components rendering");
        CompEx11 cg = new CompEx11();
        BComponent root = new BComponent();
        root.initCycle();

        //build a sample view capabilities object
        MockHttpServletRequest req = new MockHttpServletRequest();
        req.setHeader("User-Agent","Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
        ViewCapabilities vcap = new ViewCapabilities(req, null);

        //create the component amd render
        DefaultViewContext vc = new DefaultViewContext(vcap, req, null);
        Document doc = cg.handleDefault(root, vc, req, null);
        vc.setDocument(doc);                                   //csc_072604_2
        root.render(vc);
        root.destroyCycle();
        DefaultDOMWriter ddw = new DefaultDOMWriter(false);
        StringWriter sw = new StringWriter(2000);
        ddw.write(doc, sw);
        String html = sw.toString();

        //assert that there are no 'rendering failed' messages in the doc
        int fpos = html.indexOf("rendering failed");
        assertTrue("Nested component render err: "+(fpos>20 ? html.substring(fpos-20,fpos+20) : "??"), fpos<0);
        
        boolean test = false;
        //assert that label with id 'TestManualLabel' has all its children
        test = testBalanced(doc.getElementById("TestManualLabel"));
        assertTrue("Manual nested component render err: some nodes were not rendered", test);
        
        //assert that label with id 'TestTemplateLabel' has all its children
        test = testBalanced(doc.getElementById("TestTemplateLabel"));
        assertTrue("Template balanced nested component render err: some nodes were not rendered", test);

        //assert that label with id 'TestTemplateLabel' has all its children
        test = testDeep(doc.getElementById("TestTemplateDeepLabel"));
        assertTrue("Template deep nested component render err: some nodes were not rendered", test);

        //assert that label with id 'TestListLabel' has all its children
        test = testBalanced(doc.getElementById("TestListLabel"));
        assertTrue("List nested component render err: some nodes were not rendered", test);
        
        //assert that label with id 'TestTableLabel' has all its children
        test = testBalanced(doc.getElementById("TestTableLabel"));
        assertTrue("Table nested component render err: some nodes were not rendered", test);

    }
    
    private boolean testBalanced(Node n) {
    	boolean result = true;
    	Node text = n.getFirstChild();
    	if (text == null || !( text instanceof Text)) {
    		result = false;
    	}
    	Node input = text.getNextSibling();
    	if (input == null || !( input instanceof HTMLInputElement)) {
    		result = false;
    	}
    	Node image = input.getNextSibling();
    	if (image == null || !( image instanceof HTMLImageElement)) {
    		result = false;
    	}
    	return result;
    }
    
    private boolean testDeep(Node n) {
    	boolean result = true;
    	Node text = n.getFirstChild();
    	if (text == null || !( text instanceof Text)) {
    		result = false;
    	}    	
    	Node input = text.getNextSibling();
    	if (input == null || !( input instanceof HTMLInputElement)) {
    		result = false;
    	}
    	Node none = input.getNextSibling();
    	if (none != null) {
    		result = false;
    	}
    	Node image = input.getFirstChild();
    	if (image == null || !( image instanceof HTMLImageElement)) {
    		result = false;
    	}
    	return result;
    }
}
