/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestDateUtil.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.plankton;

import java.text.*;
import junit.framework.*;

import org.apache.log4j.*;
import org.barracudamvc.testbed.*;


/**
 * Test the DateUtil class
 */
public class TestDateUtil extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestDateUtil.class.getName();
    private static final Logger logger = Logger.getLogger("test."+testClass);

    //variables
    protected String sourceStr = null;
    protected String d1 = null;
    protected String d2 = null;
    protected int expectedDiff = -1;

    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestDateUtil(String name) {
        super(name);
    }

    /**
     * Public Constructor
     */
    public TestDateUtil(String name, String id1, String id2, int iexpectedDiff) {
        super(name);
        d1 = id1;
        d2 = id2;
        expectedDiff = iexpectedDiff;;
    }

    /**
     * Every test class should have a main method so it can be run
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }

    /**
     * Return a suite of tests...
     */
    public static Test suite() {
        //create the test suite
        TestSuite suite = new TestSuite();

        //add the tests
        suite.addTest(new TestDateUtil("testDateDiff", "1-3-2005", "12-28-2004", -6));
        suite.addTest(new TestDateUtil("testDateDiff", "12-28-2004", "1-3-2005", 6));

        //finally return the suite
        return suite;
    }

    //-------------------- Actual Tests --------------------------
    /**
     * Test a table to make sure it contains the expected columns
     */
    public void testDateDiff() throws ParseException {
        logger.info("running testDateDiff()");

        SimpleDateFormat sdf = new SimpleDateFormat ("MM-dd-yyyy");
        int actualDiff = DateUtil.getNumberOfDaysBetween(sdf.parse(d1), sdf.parse(d2));
        assertTrue("err diffing days:'"+d1+"', '"+d2+"' got:'"+actualDiff+"' expected:'"+expectedDiff+"'", actualDiff==expectedDiff);
    }
}
