/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestObjectRepositoryAssembler.java 141 2006-01-23 16:02:29Z christianc $
 */
package org.barracudamvc.plankton.data;

import org.apache.log4j.*;
import org.barracudamvc.testbed.*;


/**
 * This test verifies the Param object
 */
public class TestObjectRepositoryAssembler extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestObjectRepositoryAssembler.class.getName();
    private static Logger logger = Logger.getLogger("test."+testClass);

    //variables

    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestObjectRepositoryAssembler(String name) {
        super(name);
    }

    /**
     * Every test class should have a main method so it can be run
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }


    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!

    /**
     * Simple test to make sure the Param object works
     */
    public void testAssembler() {
        if (logger.isInfoEnabled()) logger.info("testing assembler");

        //get the initial values
/*        
        String INIT_TEST_STRING = ObjectRepositoryAssembler.TEST_STRING;
        int INIT_TEST_INT = ObjectRepositoryAssembler.TEST_INT;
        short INIT_TEST_SHORT = ObjectRepositoryAssembler.TEST_SHORT;
        long INIT_TEST_LONG = ObjectRepositoryAssembler.TEST_LONG;
        double INIT_TEST_DOUBLE = ObjectRepositoryAssembler.TEST_DOUBLE;
        float INIT_TEST_FLOAT = ObjectRepositoryAssembler.TEST_FLOAT;
        boolean INIT_TEST_BOOLEAN = ObjectRepositoryAssembler.TEST_BOOLEAN;
        Integer INIT_TEST_INT2 = ObjectRepositoryAssembler.TEST_INT2;
        Short INIT_TEST_SHORT2 = ObjectRepositoryAssembler.TEST_SHORT2;
        Long INIT_TEST_LONG2 = ObjectRepositoryAssembler.TEST_LONG2;
        Double INIT_TEST_DOUBLE2 = ObjectRepositoryAssembler.TEST_DOUBLE2;
        Float INIT_TEST_FLOAT2 = ObjectRepositoryAssembler.TEST_FLOAT2;
        Boolean INIT_TEST_BOOLEAN2 = ObjectRepositoryAssembler.TEST_BOOLEAN2;
*/
        //assemble into the default ObjectRepository
        new ObjectRepositoryAssembler().assemble("../../WEB-INF/object-repository-tests.xml");

        //now make sure the values got changed
        assertTrue("Failed to set TEST_CLASS", ObjectRepositoryAssembler.TEST_CLASS.equals(Param.class));
        assertTrue("Failed to set TEST_STRING", ObjectRepositoryAssembler.TEST_STRING.equals("foo"));
        assertTrue("Failed to set TEST_INT", ObjectRepositoryAssembler.TEST_INT==-99);
        assertTrue("Failed to set TEST_SHORT", ObjectRepositoryAssembler.TEST_SHORT==((short) 99));
        assertTrue("Failed to set TEST_LONG", ObjectRepositoryAssembler.TEST_LONG==((long) 99));
        assertTrue("Failed to set TEST_DOUBLE", ObjectRepositoryAssembler.TEST_DOUBLE==((double) 99));
        assertTrue("Failed to set TEST_FLOAT", ObjectRepositoryAssembler.TEST_FLOAT==((float) 99));
        assertTrue("Failed to set TEST_BOOLEAN", ObjectRepositoryAssembler.TEST_BOOLEAN==true);
        assertEquals("Failed to set TEST_INT2", ObjectRepositoryAssembler.TEST_INT2, new Integer(99));
        assertEquals("Failed to set TEST_SHORT2", ObjectRepositoryAssembler.TEST_SHORT2, new Short((short) 99));
        assertEquals("Failed to set TEST_LONG2", ObjectRepositoryAssembler.TEST_LONG2, new Long(99));
        assertEquals("Failed to set TEST_DOUBLE2", ObjectRepositoryAssembler.TEST_DOUBLE2, new Double(99));
        assertEquals("Failed to set TEST_FLOAT2", ObjectRepositoryAssembler.TEST_FLOAT2, new Float(99));
        assertEquals("Failed to set TEST_BOOLEAN2", ObjectRepositoryAssembler.TEST_BOOLEAN2, Boolean.TRUE);
        assertTrue("Failed to set TEST_STRING2", ObjectRepositoryAssembler.TEST_STRING2.equals("foo"));
        assertTrue("Failed to set TEST_STRING3", ObjectRepositoryAssembler.TEST_STRING3.equals("jujubean"));
        assertTrue("Failed to set TEST_STRING", org.barracudamvc.testbed.LocaleTestSuiteSetup.TEST_STRING.equals("foo88"));

        ObjectRepository or = ObjectRepository.getGlobalRepository();
        assertEquals("Failed to set TEST_KEY1", or.getState("TEST_KEY1").toString(), "my very elderly mother just sent us nine pizzas");
        assertEquals("Failed to set TEST_KEY2", or.getState("TEST_KEY2").toString(), "sometimes you feel like a nut, sometimes you don't");
        assertEquals("Failed to set TEST_KEY3", or.getState("TEST_KEY3"), or.getState("TEST_KEY2").toString());
        assertEquals("Failed to set TEST_KEY4", or.getState("TEST_KEY4"), ObjectRepositoryAssembler.class);
        assertTrue("Failed to set TEST_KEY5", or.getState("TEST_KEY5")!=null);

        //todo: we really ought to be testing the other aspects of this class as well (instantiating
        //an object, invoking methods on it, and placing it in the object repository)


    }
}
