/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestPArrayList.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.plankton.data;

import org.apache.log4j.*;
import org.barracudamvc.testbed.*;


/**
 * Test case for any PList
 */
public class TestPArrayList extends PListTestCases {
    //common vars (customize for every test class)
    static {
        testClass = TestPArrayList.class.getName();
        logger = Logger.getLogger("test."+testClass);
    }
    
    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestPArrayList(String name) {
        super(name);
    }
    
    /**
     * Every test class should have a main method so it can be run 
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }

    
    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!

    //NOTE: most of the individual tests are actually inherited 
    //from the parent class

    /**
     * Verify the clone (we have to test this here instead
     * the clone method is not part of the List interface...we need
     * a concrete implementation in order to be able to reference it)
     */
    public void testClone() {
        if (logger.isInfoEnabled()) logger.info("testing clone()");

        //test an empty list
        PArrayList plist1 = (PArrayList) this.getPListInstance();
        PArrayList plist2 = (PArrayList) plist1.clone();
        assertTrue("Cloned obj==source obj at 1", plist1!=plist2);
        assertEquals("Clone check 1a failed", plist1, plist2);
        assertEquals("Clone check 1b failed", plist2, plist1);

        //test a list with some items
        plist1 = (PArrayList) this.getPListInstance();
        plist1.add("foo1");
        plist1.add("foo2");
        plist1.add("foo3");
        plist1.add(new Integer(99));
        plist1.add(null);
        plist2 = (PArrayList) plist1.clone();
        assertTrue("Cloned obj==source obj at 2", plist1!=plist2);
        assertEquals("Clone check 2a failed", plist1, plist2);
        assertEquals("Clone check 2b failed", plist2, plist1);
        
        //test a list with some PData items
        plist1 = (PArrayList) this.getPListInstance();
        plist1.add("foo1");
        PList plTmp = this.getPListInstance();
        plTmp.add("blah 1");
        plTmp.add("blah 2");
        plist1.add(plTmp);
        plist2 = (PArrayList) plist1.clone();
        assertTrue("Cloned obj==source obj at 3", plist1!=plist2);
        assertEquals("Clone check 3a failed", plist1, plist2);
        assertEquals("Clone check 3b failed", plist2, plist1);
    }

    //-------------------- Abstract methods ----------------------
    public StateMap getStateMap() {
        return getPListInstance();
    }

    public PData getPDataInstance() {
        return getPListInstance();
    }

    public PList getPListInstance() {
        return new PArrayList();
    }

    public PMap getPMapInstance() {
        return new PHashMap();
    }
}
