/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 * $Id: LongRunning.template 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.examples.ex1.events;

import java.util.*;

import org.barracudamvc.core.event.*;
import org.barracudamvc.core.event.events.*;
import org.barracudamvc.plankton.data.*;

/**
 * This event indicates a local request event
 */
public class GetMainScreenSlowly extends org.barracudamvc.examples.ex1.events.MainScreenEvent implements LongRunning {

    public static Class DEFAULT_TEMPLATE = LongRunningEventGateway.DEFAULT_TEMPLATE;
    public static BaseEvent DEFAULT_REDIRECT_EVENT = new GetMainScreen();  //set to null if you don't want to specify from the events.xml file
    public static int DEFAULT_ETA = LongRunningEventGateway.DEFAULT_ETA;
    public static int DEFAULT_REFRESH_RATE = LongRunningEventGateway.DEFAULT_REFRESH_RATE;
    
    protected BaseEvent redirectEvent = null;    
    protected int eta = 30; //set to -1 if you don't want to specify from the events.xml file
    protected long start = -1;
    protected int elapsed = -1;
    protected int percentComplete = -1;
    protected StateMap statemap = null;
    protected List models = new ArrayList();
    protected Class templateClass = null;
    protected int refreshRate = -1;

    /**
     * Default noargs constructor
     */
    public GetMainScreenSlowly() {
        super();
    }

    /**
     * Public constructor. Automatically sets parameters associated 
     * with the event with a URL string of the form "key1=val1&key2=val2&..."
     * (the param str may be prefixed by a '?')
     */
    public GetMainScreenSlowly(String urlParamStr) {
        super(urlParamStr);
    }

    /**
     * Public constructor. Automatically sets the source parameter.
     * If you do not use this method you should manually set the
     * source before dispatching the event.
     */
    public GetMainScreenSlowly(Object source) {
        super(source);
    }

    /**
     * Specify the redirect event to be fired if the LongRunning process is cancelled
     */
    public void setRedirectEvent(BaseEvent be) {
        redirectEvent = be;
    }
    
    /**
     * get the redirect event for this LongRunning process. If the ETA has not been set, 
     * DEFAULT_ETA will be returned. Typically called by LongRunningEventGateway.
     */
    public BaseEvent getRedirectEvent() {
        return (redirectEvent!=null ? redirectEvent : DEFAULT_REDIRECT_EVENT);
    }
    
    /**
     * set the refresh rate (in secs). -1 indicates the DEFAULT_REFRESH_RATE will be used
     */
    public void setRefreshRate(int secs) {
        refreshRate = secs;
    }
    
    /**
     * get the refresh rate (in secs). If the refresh rate has not been set, 
     * DEFAULT_REFRESH_RATE will be returned.
     */
    public int getRefreshRate() {
        return (refreshRate!=-1 ? refreshRate : DEFAULT_REFRESH_RATE);
    }
    
    /**
     * set ETA (in secs). -1 indicates the DEFAULT_ETA will be used
     */
    public void setETA(int secs) {
        eta = secs;
    }
    
    /**
     * get ETA (in secs). If the ETA has not been set, DEFAULT_ETA will be returned.
     */
    public int getETA() {
        return (eta!=-1 ? eta : DEFAULT_ETA);
    }
    
    /**
     * set elapsed (in secs). This can be called by the developer's event handler code if desired 
     * to manually specify how much time has elapsed. If you don't call this method, elapsed time
     * be determined dynamically by comparing the amount of time elapsed from object creation.
     */
    public void setElapsed(int secs) {
        elapsed = secs;
    }
    
    /**
     * get elapsed (in secs). If a elapsed time has not been programatically specified, 
     * it will be calulated dynamically. Typically called by LongRunningEventGateway.
     */
    public int getElapsed() {
        if (elapsed!=-1) {
            return elapsed;
        } else {
            return (int) ((System.currentTimeMillis()-start)/1000);
        }
    }

    /**
     * set the percent complete (int between 0 and 100). This can be called by the developer's event
     * handler code if desired to manually specify completion percent. If you don't call this method,
     * percent completed will be determined dynamically by comparing the amount of time elapsed with ETA.
     */
    public void setPercentComplete(int percent) {
        if (percent<0) percent = -1;
        else if (percent>100) percent = 100;
        percentComplete = percent;
    }
    
    /**
     * get the percent complete (int between 0 and 100). If a percentage complete has not been 
     * programatically specified, it will be calulated dynamically. Typically called by 
     * LongRunningEventGateway.
     */
    public int getPercentComplete() {
        int percent = percentComplete;
        if (percent==-1.0) {
            percent = (int) (getElapsed() * 100 / getETA());
            if (percent>99) percent = 99;
        }
        if (percent<0) percent = 0;
        else if (percent>100) percent = 100;
        return percent;
    }

    /**
     * get the statemap (may be used for storing key/val info, which can then
     * be retrieved from the template). Typically called by the developer's event handling code to 
     * set some kind of value, and then by LongRunningEventGateway to retrieve that value when 
     * requested by the template.
     */
    public StateMap getStateMap() {
        if (statemap==null) statemap = new DefaultStateMap();
        return statemap;
    }

    /**
     * provide a List of additional BTemplate models to make available during to the 
     * LongRunningEventGateway template. This method would be called by the developers event 
     * handler code to provide additional models for the template to access.
     */
    public void setAdditionalModels(List imodels) {
        models = imodels;
    }

    /**
     * get any additional BTemplate models. Typically called by LongRunningEventGateway.
     */
    public List getAdditionalModels() {
        return models;
    }

    /**
     * provide a different Template class instead of the default Barracuda template, This
     * will typically be used by developers who want to override L&F of the progress screen.
     */
    public void setTemplateClass(Class cl) {
        templateClass = cl;
    }

    /**
     * get the custom template class. Typically called by LongRunningEventGateway.
     */
    public Class getTemplateClass() {
        return (templateClass!=null ? templateClass : DEFAULT_TEMPLATE);
    }
    
    /**
     * resets the start time. Typically called by ApplicationGateway prior to dispatching.
     */
    public void reset() {
        start = System.currentTimeMillis();
    }    
}
